Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(404)

Unified Diff: lib/src/io.dart

Issue 1161873009: Expect pub to live in pkg_tested in the SDK repo. (Closed) Base URL: git@github.com:dart-lang/pub.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/src/io.dart
diff --git a/lib/src/io.dart b/lib/src/io.dart
index 10a08b644c53865078c6323a6ce3f454c21bcc4e..92259fd5ae34c57933b145c9d785d1cb39332505 100644
--- a/lib/src/io.dart
+++ b/lib/src/io.dart
@@ -497,7 +497,7 @@ final bool runningFromSdk =
///
/// This can happen when building Observatory, for example.
final bool runningFromDartRepo =
- Platform.script.path.endsWith('/third_party/pkg/pub/bin/pub.dart');
+ Platform.script.path.endsWith('/third_party/pkg_tested/pub/bin/pub.dart');
/// Resolves [target] relative to the path to pub's `asset` directory.
String assetPath(String target) => runningFromSdk
@@ -546,7 +546,7 @@ final String dartRepoRoot = (() {
throw new StateError("Not running from source in the Dart repo.");
}
// In the Dart repo, the script is in "third_party/pkg/pub/bin".
return path.dirname(path.dirname(path.dirname(path.dirname(path.dirname(
path.fromUri(Platform.script))))));
})();
@@ -546,7 +546,7 @@ final String dartRepoRoot = (() {
throw new StateError("Not running from source in the Dart repo.");
}
- // In the Dart repo, the script is in "third_party/pkg/pub/bin".
+ // In the Dart repo, the script is in "third_party/pkg_tested/pub/bin".
return path.dirname(path.dirname(path.dirname(path.dirname(path.dirname(
path.fromUri(Platform.script))))));
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698